==> istio-model-v1alpha3-6.3.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectPatchFluentImpl<A extends EnvoyFilterEnvoyConfigObjectPatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectPatchFluent<A>{
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl(EnvoyFilterEnvoyConfigObjectPatch instance) {
    this.withApplyTo(instance.getApplyTo()); 
    this.withMatch(instance.getMatch()); 
    this.withPatch(instance.getPatch()); 
  }
  private EnvoyFilterApplyTo applyTo;
  private EnvoyFilterEnvoyConfigObjectMatchBuilder match;
  private EnvoyFilterPatchBuilder patch;
  public EnvoyFilterApplyTo getApplyTo() {
    return this.applyTo;
  }
  public A withApplyTo(EnvoyFilterApplyTo applyTo) {
    this.applyTo=applyTo; return (A) this;
  }
  public Boolean hasApplyTo() {
    return this.applyTo != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterEnvoyConfigObjectMatch getMatch() {
    return this.match!=null ?this.match.build():null;
  }
  public EnvoyFilterEnvoyConfigObjectMatch buildMatch() {
    return this.match!=null ?this.match.build():null;
  }
  public A withMatch(EnvoyFilterEnvoyConfigObjectMatch match) {
    _visitables.get("match").remove(this.match);
    if (match!=null){ this.match= new EnvoyFilterEnvoyConfigObjectMatchBuilder(match); _visitables.get("match").add(this.match);} else { this.match = null; _visitables.get("match").remove(this.match); } return (A) this;
  }
  public Boolean hasMatch() {
    return this.match != null;
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<A> withNewMatch() {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<A> withNewMatchLike(EnvoyFilterEnvoyConfigObjectMatch item) {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<A> editMatch() {
    return withNewMatchLike(getMatch());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<A> editOrNewMatch() {
    return withNewMatchLike(getMatch() != null ? getMatch(): new EnvoyFilterEnvoyConfigObjectMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<A> editOrNewMatchLike(EnvoyFilterEnvoyConfigObjectMatch item) {
    return withNewMatchLike(getMatch() != null ? getMatch(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterPatch getPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public EnvoyFilterPatch buildPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public A withPatch(EnvoyFilterPatch patch) {
    _visitables.get("patch").remove(this.patch);
    if (patch!=null){ this.patch= new EnvoyFilterPatchBuilder(patch); _visitables.get("patch").add(this.patch);} else { this.patch = null; _visitables.get("patch").remove(this.patch); } return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<A> withNewPatch() {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<A> withNewPatchLike(EnvoyFilterPatch item) {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<A> editPatch() {
    return withNewPatchLike(getPatch());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(getPatch() != null ? getPatch(): new EnvoyFilterPatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<A> editOrNewPatchLike(EnvoyFilterPatch item) {
    return withNewPatchLike(getPatch() != null ? getPatch(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterEnvoyConfigObjectPatchFluentImpl that = (EnvoyFilterEnvoyConfigObjectPatchFluentImpl) o;
    if (applyTo != null ? !applyTo.equals(that.applyTo) :that.applyTo != null) return false;
    if (match != null ? !match.equals(that.match) :that.match != null) return false;
    if (patch != null ? !patch.equals(that.patch) :that.patch != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applyTo,  match,  patch,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applyTo != null) { sb.append("applyTo:"); sb.append(applyTo + ","); }
    if (match != null) { sb.append("match:"); sb.append(match + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch); }
    sb.append("}");
    return sb.toString();
  }
  class MatchNestedImpl<N> extends EnvoyFilterEnvoyConfigObjectMatchFluentImpl<EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<N>> implements EnvoyFilterEnvoyConfigObjectPatchFluent.MatchNested<N>,Nested<N>{
    MatchNestedImpl(EnvoyFilterEnvoyConfigObjectMatch item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchBuilder(this, item);
    }
    MatchNestedImpl() {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchBuilder(this);
    }
    EnvoyFilterEnvoyConfigObjectMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectPatchFluentImpl.this.withMatch(builder.build());
    }
    public N endMatch() {
      return and();
    }
    
  }
  class PatchNestedImpl<N> extends EnvoyFilterPatchFluentImpl<EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<N>> implements EnvoyFilterEnvoyConfigObjectPatchFluent.PatchNested<N>,Nested<N>{
    PatchNestedImpl(EnvoyFilterPatch item) {
      this.builder = new EnvoyFilterPatchBuilder(this, item);
    }
    PatchNestedImpl() {
      this.builder = new EnvoyFilterPatchBuilder(this);
    }
    EnvoyFilterPatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectPatchFluentImpl.this.withPatch(builder.build());
    }
    public N endPatch() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectPatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterEnvoyConfigObjectPatchFluentImpl<A extends EnvoyFilterEnvoyConfigObjectPatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterEnvoyConfigObjectPatchFluent<A>{
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl() {
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl(EnvoyFilterEnvoyConfigObjectPatch instance) {
    if (instance != null) {
      this.withApplyTo(instance.getApplyTo());
      this.withMatch(instance.getMatch());
      this.withPatch(instance.getPatch());
    }
  }
  private EnvoyFilterApplyTo applyTo;
  private EnvoyFilterEnvoyConfigObjectMatchBuilder match;
  private EnvoyFilterPatchBuilder patch;
  public EnvoyFilterApplyTo getApplyTo() {
    return this.applyTo;
  }
  public A withApplyTo(EnvoyFilterApplyTo applyTo) {
    this.applyTo=applyTo; return (A) this;
  }
  public Boolean hasApplyTo() {
    return this.applyTo != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterEnvoyConfigObjectMatch getMatch() {
    return this.match!=null ?this.match.build():null;
  }
  public EnvoyFilterEnvoyConfigObjectMatch buildMatch() {
    return this.match!=null ?this.match.build():null;
  }
  public A withMatch(EnvoyFilterEnvoyConfigObjectMatch match) {
    _visitables.get("match").remove(this.match);
    if (match!=null){ this.match= new EnvoyFilterEnvoyConfigObjectMatchBuilder(match); _visitables.get("match").add(this.match);} else { this.match = null; _visitables.get("match").remove(this.match); } return (A) this;
  }
  public Boolean hasMatch() {
    return this.match != null;
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<A> withNewMatch() {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<A> withNewMatchLike(EnvoyFilterEnvoyConfigObjectMatch item) {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<A> editMatch() {
    return withNewMatchLike(getMatch());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<A> editOrNewMatch() {
    return withNewMatchLike(getMatch() != null ? getMatch(): new EnvoyFilterEnvoyConfigObjectMatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<A> editOrNewMatchLike(EnvoyFilterEnvoyConfigObjectMatch item) {
    return withNewMatchLike(getMatch() != null ? getMatch(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public EnvoyFilterPatch getPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public EnvoyFilterPatch buildPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public A withPatch(EnvoyFilterPatch patch) {
    _visitables.get("patch").remove(this.patch);
    if (patch!=null){ this.patch= new EnvoyFilterPatchBuilder(patch); _visitables.get("patch").add(this.patch);} else { this.patch = null; _visitables.get("patch").remove(this.patch); } return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<A> withNewPatch() {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNestedImpl();
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<A> withNewPatchLike(EnvoyFilterPatch item) {
    return new EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNestedImpl(item);
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<A> editPatch() {
    return withNewPatchLike(getPatch());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(getPatch() != null ? getPatch(): new EnvoyFilterPatchBuilder().build());
  }
  public EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<A> editOrNewPatchLike(EnvoyFilterPatch item) {
    return withNewPatchLike(getPatch() != null ? getPatch(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterEnvoyConfigObjectPatchFluentImpl that = (EnvoyFilterEnvoyConfigObjectPatchFluentImpl) o;
    if (!java.util.Objects.equals(applyTo, that.applyTo)) return false;

    if (!java.util.Objects.equals(match, that.match)) return false;

    if (!java.util.Objects.equals(patch, that.patch)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(applyTo,  match,  patch,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (applyTo != null) { sb.append("applyTo:"); sb.append(applyTo + ","); }
    if (match != null) { sb.append("match:"); sb.append(match + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch); }
    sb.append("}");
    return sb.toString();
  }
  class MatchNestedImpl<N> extends EnvoyFilterEnvoyConfigObjectMatchFluentImpl<EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<N>> implements EnvoyFilterEnvoyConfigObjectPatchFluentImpl.MatchNested<N>,Nested<N>{
    MatchNestedImpl(EnvoyFilterEnvoyConfigObjectMatch item) {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchBuilder(this, item);
    }
    MatchNestedImpl() {
      this.builder = new EnvoyFilterEnvoyConfigObjectMatchBuilder(this);
    }
    EnvoyFilterEnvoyConfigObjectMatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectPatchFluentImpl.this.withMatch(builder.build());
    }
    public N endMatch() {
      return and();
    }
    
  }
  class PatchNestedImpl<N> extends EnvoyFilterPatchFluentImpl<EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<N>> implements EnvoyFilterEnvoyConfigObjectPatchFluentImpl.PatchNested<N>,Nested<N>{
    PatchNestedImpl(EnvoyFilterPatch item) {
      this.builder = new EnvoyFilterPatchBuilder(this, item);
    }
    PatchNestedImpl() {
      this.builder = new EnvoyFilterPatchBuilder(this);
    }
    EnvoyFilterPatchBuilder builder;
    public N and() {
      return (N) EnvoyFilterEnvoyConfigObjectPatchFluentImpl.this.withPatch(builder.build());
    }
    public N endPatch() {
      return and();
    }
    
  }
  
}
